## Summary

## search

### API search

ℹ️ Restriction: API searches do not support complex queries (yet)

```
colrev search --add colrev.open_alex -p "..."
```

## prep

Links meta data from OpenAlex to existing records.

## Debugging

To test the metadata provided for a particular `open_alex_id` use:
```
https://api.openalex.org/works/OPEN_ALEX_ID
```

## Links

- [OpenAlex](https://openalex.org/)
- [License](https://docs.openalex.org/additional-help/faq#how-is-openalex-licensed)
